@@ -1,3 +1,4 @@
+"""Module provider for Aurora"""
 from __future__ import absolute_import
 import base64
 import datetime
@@ -15,7 +16,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['auroradns.eu']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for Aurora"""
     subparser.add_argument(
         "--auth-api-key", help="specify API key for authentication")
     subparser.add_argument("--auth-secret-key",
@@ -23,13 +25,13 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
-
+    """Provider for Aurora"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://api.auroradns.eu'
 
-    def authenticate(self):
+    def _authenticate(self):
         zone = None
         payload = self._get('/zones')
 
@@ -43,33 +45,35 @@ class Provider(BaseProvider):
         self.domain_id = zone['id']
 
     # Create record. If record already exists with the same content, do nothing'
-    def create_record(self, type, name, content):
-        data = {'type': type, 'name': self._relative_name(
+    def _create_record(self, rtype, name, content):
+        data = {'type': rtype, 'name': self._relative_name(
             name), 'content': content}
         if self._get_lexicon_option('ttl'):
             data['ttl'] = self._get_lexicon_option('ttl')
         payload = self._post('/zones/{0}/records'.format(self.domain_id), data)
 
-        LOGGER.debug('create_record: {0}'.format(payload))
+        LOGGER.debug('create_record: %s', payload)
         return payload
 
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         payload = self._get('/zones/{0}/records'.format(self.domain_id))
 
         # Apply filtering first.
         processed_records = payload
-        if type:
+        if rtype:
             processed_records = [
-                record for record in processed_records if record['type'] == type]
+                record for record in processed_records if record['type'] == rtype]
         if name:
             processed_records = [
-                record for record in processed_records if record['name'] == self._relative_name(name)]
+                record for record in processed_records
+                if record['name'] == self._relative_name(name)]
         if content:
             processed_records = [
-                record for record in processed_records if record['content'].lower() == content.lower()]
+                record for record in processed_records
+                if record['content'].lower() == content.lower()]
 
         # Format the records.
         records = []
@@ -87,14 +91,14 @@ class Provider(BaseProvider):
         return records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         # Try to find record if no identifier was specified
         if not identifier:
-            identifier = self._find_record_identifier(type, name, None)
+            identifier = self._find_record_identifier(rtype, name, None)
 
         data = {}
-        if type:
-            data['type'] = type
+        if rtype:
+            data['type'] = rtype
         if name:
             data['name'] = self._relative_name(name)
         if content:
@@ -110,11 +114,11 @@ class Provider(BaseProvider):
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         # Try to find record if no identifier was specified
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -122,7 +126,7 @@ class Provider(BaseProvider):
         LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._delete(
+            self._delete(
                 '/zones/{0}/records/{1}'.format(self.domain_id, record_id))
 
         LOGGER.debug('delete_record: %s', True)
@@ -136,30 +140,30 @@ class Provider(BaseProvider):
         if query_params is None:
             query_params = {}
 
-        t = datetime.datetime.utcnow()
-        timestamp = t.strftime('%Y%m%dT%H%M%SZ')
+        time = datetime.datetime.utcnow()
+        timestamp = time.strftime('%Y%m%dT%H%M%SZ')
         authorization_header = self._generate_auth_header(
             action, url, timestamp)
 
-        r = requests.request(action, self.api_endpoint + url, params=query_params,
-                             data=json.dumps(data),
-                             headers={
-                                 'X-AuroraDNS-Date': timestamp,
-                                 'Authorization': authorization_header,
-                                 'Content-Type': 'application/json'
-                             })
+        request = requests.request(action, self.api_endpoint + url, params=query_params,
+                                   data=json.dumps(data),
+                                   headers={
+                                       'X-AuroraDNS-Date': timestamp,
+                                       'Authorization': authorization_header,
+                                       'Content-Type': 'application/json'
+                                   })
 
         # If the response is a HTTP 409 statusCode, the record already exists: return true.
-        if r.status_code == 409:
+        if request.status_code == 409:
             return True
 
         # If the request fails for any other reason, throw an error.
-        r.raise_for_status()
+        request.raise_for_status()
 
         # Try to parse the json, if it not exists, return true.
         try:
-            return r.json()
-        except:
+            return request.json()
+        except BaseException:
             return True
 
     def _generate_auth_header(self, action, url, timestamp):
@@ -175,11 +179,9 @@ class Provider(BaseProvider):
         auth_b64 = base64.b64encode(auth.encode('utf-8'))
         return 'AuroraDNSv1 %s' % (auth_b64.decode('utf-8'))
 
-    def _find_record_identifier(self, type, name, content):
-        records = self.list_records(type, name, content)
+    def _find_record_identifier(self, rtype, name, content):
+        records = self._list_records(rtype, name, content)
         LOGGER.debug('records: %s', records)
         if len(records) == 1:
             return records[0]['id']
-        else:
-            raise Exception(
-                'Record identifier could not be found. Try to provide an identifier')
+        raise Exception('Record identifier could not be found. Try to provide an identifier')
