@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+"""Module provider for DNSPod"""
 from __future__ import absolute_import
 
 import logging
@@ -12,7 +12,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['dnsapi.cn']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for DNSPod"""
     subparser.add_argument(
         "--auth-username", help="specify api id for authentication")
     subparser.add_argument(
@@ -20,13 +21,13 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
-
+    """Provider class for DNSPod"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://dnsapi.cn'
 
-    def authenticate(self):
+    def _authenticate(self):
 
         payload = self._post('/Domain.Info', {'domain': self.domain})
 
@@ -36,13 +37,12 @@ class Provider(BaseProvider):
         self.domain_id = payload['domain']['id']
 
     # Create record. If record already exists with the same content, do nothing'
-
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         record = {
             'domain_id': self.domain_id,
             'sub_domain': self._relative_name(name),
-            'record_type': type,
-            'record_line': '默认',
+            'record_type': rtype,
+            'record_line': u'\u9ED8\u8BA4',
             'value': content
         }
         if self._get_lexicon_option('ttl'):
@@ -59,9 +59,7 @@ class Provider(BaseProvider):
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
-        filter = {}
-
+    def _list_records(self, rtype=None, name=None, content=None):
         payload = self._post('/Record.List', {'domain': self.domain})
         LOGGER.debug('payload: %s', payload)
         records = []
@@ -77,8 +75,8 @@ class Provider(BaseProvider):
             }
             records.append(processed_record)
 
-        if type:
-            records = [record for record in records if record['type'] == type]
+        if rtype:
+            records = [record for record in records if record['type'] == rtype]
         if name:
             records = [record for record in records if record['name']
                        == self._full_name(name)]
@@ -90,14 +88,14 @@ class Provider(BaseProvider):
         return records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
 
         data = {
             'domain_id': self.domain_id,
             'record_id': identifier,
             'sub_domain': self._relative_name(name),
-            'record_type': type,
-            'record_line': '默认',
+            'record_type': rtype,
+            'record_line': u'\u9ED8\u8BA4',
             'value': content
         }
         if self._get_lexicon_option('ttl'):
@@ -113,10 +111,10 @@ class Provider(BaseProvider):
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -124,7 +122,7 @@ class Provider(BaseProvider):
         LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._post(
+            self._post(
                 '/Record.Remove', {'domain_id': self.domain_id, 'record_id': record_id})
 
             # if payload['status']['code'] != '1':
@@ -136,7 +134,7 @@ class Provider(BaseProvider):
 
     # Helpers
 
-    def _request(self, action='GET',  url='/', data=None, query_params=None):
+    def _request(self, action='GET', url='/', data=None, query_params=None):
         if data is None:
             data = {}
         data['login_token'] = self._get_provider_option(
@@ -146,10 +144,10 @@ class Provider(BaseProvider):
             query_params = {}
         default_headers = {}
         default_auth = None
-        r = requests.request(action, self.api_endpoint + url, params=query_params,
-                             data=data,
-                             headers=default_headers,
-                             auth=default_auth)
+        response = requests.request(action, self.api_endpoint + url, params=query_params,
+                                    data=data,
+                                    headers=default_headers,
+                                    auth=default_auth)
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        return r.json()
+        response.raise_for_status()
+        return response.json()
