@@ -38,26 +38,31 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['googledomains.com']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Generate a subparser for Google Cloud DNS"""
     subparser.description = '''
         The Google Cloud DNS provider requires the JSON file which contains the service account info to connect to the API.
         This service account must own the project role DNS > DNS administrator for the project associated to the DNS zone.
-        You can create a new service account, associate a private key, and download its info through this url: 
+        You can create a new service account, associate a private key, and download its info through this url:
         https://console.cloud.google.com/iam-admin/serviceaccounts?authuser=2'''
     subparser.add_argument('--auth-service-account-info', help='''
-        specify the service account info in the Google JSON format: 
+        specify the service account info in the Google JSON format:
         can be either the path of a file prefixed by 'file::' (eg. file::/tmp/service_account_info.json)
-        or the base64 encoded content of this file prefixed by 'base64::' (eg. base64::eyJhbGciOyJ...)''')
+        or the base64 encoded content of this file prefixed by 'base64::'
+        (eg. base64::eyJhbGciOyJ...)''')
 
 
 class Provider(BaseProvider):
+    """
+    Provider class for Google Cloud DNS
 
-    # We need serveral parameters, which are available in the JSON file provided
-    #   by Google when associating a private key to the relevant service account.
-    # So this JSON file is the natural input to configure the provider.
-    # It can be provided as a path to the JSON file, or as its content encoded
-    #   in base64, which is a suitable portable way in particular for Docker containers.
-    # In both cases the content is loaded as bytes, on loaded in a private instance variable.
+    We need serveral parameters, which are available in the JSON file provided
+    by Google when associating a private key to the relevant service account.
+    So this JSON file is the natural input to configure the provider.
+    It can be provided as a path to the JSON file, or as its content encoded
+    in base64, which is a suitable portable way in particular for Docker containers.
+    In both cases the content is loaded as bytes, on loaded in a private instance variable.
+    """
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
@@ -65,7 +70,7 @@ class Provider(BaseProvider):
 
         if self._get_provider_option('auth_service_account_info').startswith('file::'):
             with open(self._get_provider_option('auth_service_account_info')
-                              .replace('file::', ''), 'rb') as file:
+                      .replace('file::', ''), 'rb') as file:
                 service_account_info_bytes = file.read()
         elif self._get_provider_option('auth_service_account_info').startswith('base64::'):
             service_account_info_bytes = b64decode(self._get_provider_option(
@@ -95,7 +100,7 @@ class Provider(BaseProvider):
     #     the managed zone id, which will also be used on future requests.
     # This access token has a default lifetime of 10 minutes,
     # but is used only for the current Lexicon operation, so it should be sufficient.
-    def authenticate(self):
+    def _authenticate(self):
         jwt_header_bytes = urlsafe_b64encode(json.dumps({
             'alg': 'RS256',
             'typ': 'JWT'
@@ -140,7 +145,7 @@ class Provider(BaseProvider):
         if not post_result['access_token']:
             raise Exception('Error, could not grant RW access on the '
                             'Google Cloud DNS API for user: {0}'.format(
-                self._get_provider_option('auth_email')))
+                                self._get_provider_option('auth_email')))
 
         self._token = post_result['access_token']
 
@@ -163,7 +168,7 @@ class Provider(BaseProvider):
     # name is not always available (we can ask for every TXT record for example). So to stick to
     # the most general case, its preferable to always get all records and be free to filter
     # the way we want afterwards.
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         results = self._get('/managedZones/{0}/rrsets'.format(self.domain_id))
 
         records = []
@@ -180,8 +185,8 @@ class Provider(BaseProvider):
                 record['id'] = Provider._identifier(record)
                 records.append(record)
 
-        if type:
-            records = [record for record in records if record['type'] == type]
+        if rtype:
+            records = [record for record in records if record['type'] == rtype]
         if name:
             records = [record for record in records if record['name']
                        == self._full_name(name)]
@@ -198,16 +203,16 @@ class Provider(BaseProvider):
     # Indeed we need to know if there is already a RecordSet for the type/name pair, and update
     # or create accordingly the RecordSet. Furthermore, we need first to delete the old RecordSet
     # if it exists, to replace it with the RecordSet containing the new content we want.
-    def create_record(self, type, name, content):
-        if not type or not name or not content:
+    def _create_record(self, rtype, name, content):
+        if not rtype or not name or not content:
             raise Exception(
-                'Error, type, name and content are mandatory to create a record.')
+                'Error, rtype, name and content are mandatory to create a record.')
 
         identifier = Provider._identifier(
-            {'type': type, 'name': self._full_name(name), 'content': content})
+            {'type': rtype, 'name': self._full_name(name), 'content': content})
 
         query_params = {
-            'type': type,
+            'type': rtype,
             'name': self._fqdn_name(name)
         }
 
@@ -233,11 +238,11 @@ class Provider(BaseProvider):
 
             rrdatas = rrset['rrdatas'][:]
 
-        rrdatas.append(Provider._normalize_content(type, content))
+        rrdatas.append(Provider._normalize_content(rtype, content))
 
         changes['additions'] = [{
             'name': self._fqdn_name(name),
-            'type': type,
+            'type': rtype,
             'ttl': self._get_lexicon_option('ttl'),
             'rrdatas': rrdatas
         }]
@@ -258,17 +263,17 @@ class Provider(BaseProvider):
     # Even if this make the operation very costly regarding the number of requests to do, it allows
     # the implementation to be way more readable (without that, it would take grossly the size of
     # he three quoted methods).
-    def update_record(self, identifier, type=None, name=None, content=None):
-        if not identifier and (not type or not name):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
+        if not identifier and (not rtype or not name):
             raise Exception(
-                'Error, identifier or type+name parameters are required.')
+                'Error, identifier or rtype+name parameters are required.')
 
         if identifier:
-            records = self.list_records()
+            records = self._list_records()
             records_to_update = [
                 record for record in records if record['id'] == identifier]
         else:
-            records_to_update = self.list_records(type=type, name=name)
+            records_to_update = self._list_records(rtype=rtype, name=name)
 
         if not records_to_update:
             raise Exception(
@@ -283,15 +288,15 @@ class Provider(BaseProvider):
 
         original_level = LOGGER.getEffectiveLevel()
         LOGGER.setLevel(logging.WARNING)
-        self.delete_record(record_identifier)
+        self._delete_record(record_identifier)
 
         new_record = {
-            'type': type if type else records_to_update[0]['type'],
+            'type': rtype if rtype else records_to_update[0]['type'],
             'name': name if name else records_to_update[0]['name'],
             'content': content if content else records_to_update[0]['content']
         }
 
-        self.create_record(
+        self._create_record(
             new_record['type'], new_record['name'], new_record['content'])
         LOGGER.setLevel(original_level)
 
@@ -314,7 +319,7 @@ class Provider(BaseProvider):
     #   - mark as addition the update RecordSet with the subset of rrdatas if rrdatas is not empty
     #   - do not mark as additions RecordSets whose rrdatas subset become empty:
     #     for this type/name pair, all RecordSet needs to go away.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         results = self._get('/managedZones/{0}/rrsets'.format(self.domain_id))
 
         if identifier:
@@ -322,7 +327,7 @@ class Provider(BaseProvider):
                 results, identifier)
         else:
             changes = self._process_records_to_delete_by_parameters(
-                results, type, name, content)
+                results, rtype, name, content)
 
         if not changes:
             raise Exception(
@@ -332,7 +337,7 @@ class Provider(BaseProvider):
             '/managedZones/{0}/changes'.format(self.domain_id), data=changes)
 
         LOGGER.debug('delete_records: %s %s %s %s',
-                     identifier, type, name, content)
+                     identifier, rtype, name, content)
 
         return True
 
@@ -362,12 +367,12 @@ class Provider(BaseProvider):
     # rrdatas after its subset are not marked in additions to be completely removed
     # from the DNS zone.
     def _process_records_to_delete_by_parameters(
-            self, results, type=None, name=None, content=None):
+            self, results, rtype=None, name=None, content=None):
         rrsets_to_modify = results['rrsets']
 
-        if type:
+        if rtype:
             rrsets_to_modify = [
-                rrset for rrset in rrsets_to_modify if rrset['type'] == type]
+                rrset for rrset in rrsets_to_modify if rrset['type'] == rtype]
         if name:
             rrsets_to_modify = [
                 rrset for rrset in rrsets_to_modify if rrset['name'] == self._fqdn_name(name)]
@@ -408,10 +413,10 @@ class Provider(BaseProvider):
     # With Google Cloud DNS API, content of CNAME entries must be FQDN (with a trailing dot),
     #   and content of TXT entries must be quoted. This static method ensures that.
     @staticmethod
-    def _normalize_content(type, content):
-        if type == 'TXT':
+    def _normalize_content(rtype, content):
+        if rtype == 'TXT':
             return '"{0}"'.format(content)
-        if type == 'CNAME':
+        if rtype == 'CNAME':
             return '{0}.'.format(content) if not content.endswith('.') else content
 
         return content
