@@ -1,3 +1,4 @@
+"""Module provider for Linode V4"""
 from __future__ import absolute_import
 import json
 import logging
@@ -11,38 +12,39 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['linode.com']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for Linode V4"""
     subparser.add_argument(
         "--auth-token", help="specify api key for authentication")
 
 
 class Provider(BaseProvider):
-
+    """Provider class for Linode V4"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://api.linode.com/v4/'
 
-    def authenticate(self):
+    def _authenticate(self):
         self.domain_id = None
         payload = self._get('domains', query_params={
             'filter': {
-                'domain': self.domain
+                'domain': self.domain.lower()
             }
         })
-        if len(payload['data']) > 0:
+        if payload['data']:
             self.domain_id = payload['data'][0]['id']
         if self.domain_id is None:
             raise Exception('Domain not found')
 
-    def create_record(self, type, name, content):
-        if len(self.list_records(type, name, content)) == 0:
+    def _create_record(self, rtype, name, content):
+        if not self._list_records(rtype, name, content):
             if name:
-                name = self._relative_name(name)
+                name = self._relative_name(name).lower()
 
             self._post('domains/{0}/records'.format(self.domain_id), data={
                 'name': name,
-                'type': type,
+                'type': rtype,
                 'target': content,
                 'ttl_sec': 0
             })
@@ -52,11 +54,11 @@ class Provider(BaseProvider):
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         resources_url = "domains/{0}/records".format(self.domain_id)
 
         if name:
-            name = self._relative_name(name)
+            name = self._relative_name(name).lower()
 
         processed_records = []
 
@@ -68,12 +70,12 @@ class Provider(BaseProvider):
                 })
 
             resource_list = payload['data']
-            if type:
+            if rtype:
                 resource_list = [
-                    resource for resource in resource_list if resource['type'] == type]
+                    resource for resource in resource_list if resource['type'] == rtype]
             if name:
                 resource_list = [resource for resource in resource_list if self._relative_name(
-                    resource['name']) == name]
+                    resource['name']).lower() == name]
             if content:
                 resource_list = [
                     resource for resource in resource_list if resource['target'] == content]
@@ -82,7 +84,7 @@ class Provider(BaseProvider):
                 processed_records.append({
                     'id': resource['id'],
                     'type': resource['type'],
-                    'name': self._full_name(resource['name']),
+                    'name': self._full_name(resource['name']).lower(),
                     'ttl': resource['ttl_sec'],
                     'content': resource['target']
                 })
@@ -91,20 +93,20 @@ class Provider(BaseProvider):
         return processed_records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         if not identifier:
-            resources = self.list_records(type, name, None)
-            identifier = resources[0]['id'] if len(resources) > 0 else None
+            resources = self._list_records(rtype, name, None)
+            identifier = resources[0]['id'] if resources else None
 
         LOGGER.debug('update_record: %s', identifier)
 
         if name:
-            name = self._relative_name(name)
+            name = self._relative_name(name).lower()
 
         url = 'domains/{0}/records/{1}'.format(self.domain_id, identifier)
         self._put(url, data={
             'name': name.lower() if name else None,
-            'type': type if type else None,
+            'type': rtype if rtype else None,
             'target': content if content else None
         })
 
@@ -112,10 +114,10 @@ class Provider(BaseProvider):
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_resource_id = []
         if not identifier:
-            resources = self.list_records(type, name, content)
+            resources = self._list_records(rtype, name, content)
             delete_resource_id = [resource['id'] for resource in resources]
         else:
             delete_resource_id.append(identifier)
@@ -131,7 +133,7 @@ class Provider(BaseProvider):
         return True
 
     # Helpers
-    def _request(self, action='GET',  url='', data=None, query_params=None):
+    def _request(self, action='GET', url='', data=None, query_params=None):
         if data is None:
             data = {}
         if query_params is None:
@@ -149,13 +151,12 @@ class Provider(BaseProvider):
 
         request_url = "{0}{1}".format(self.api_endpoint, url)
 
-        r = requests.request(action, request_url, params=query_params,
-                             data=json.dumps(data),
-                             headers=default_headers)
+        response = requests.request(action, request_url, params=query_params,
+                                    data=json.dumps(data),
+                                    headers=default_headers)
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
+        response.raise_for_status()
         if action == 'DELETE':
             return ''
-        else:
-            result = r.json()
-            return result
+        result = response.json()
+        return result
